User API
====================================

To call **AeroMesh** from within a process, use one of the two following API calls depending on need. Fill out a dictionary
using :ref:`the schema <yaml_params>` and pass it as an argument for successful execution.

3D Meshing
------------------

.. autofunction:: aeromesh.generate3DMesh

2D Meshing
------------------

.. autofunction:: aeromesh.generate2DMesh